/**
 * Created with WebStorm.
 * User: gp
 * Date: 16-2-24
 *
 */

import React, { Component } from 'react';
import getLinkButtonTheme from './styles/linkButton'

class LinkButton extends Component {

    /**
     * props有： title,icon,color,  iconStyle, hide
     *
     *
     *
     * @param props
     * @param context
     */
    constructor(props, context) {
        super(props, context);
        this.state = this._buildStates(props);
    }

    render() {
        const  props = this.props;
        const theme = this._processTheme(props);
        let events = {
            onMouseDown: this._onMouseDown.bind(this),
            onMouseUp: this._onMouseUp.bind(this)
        }
        if(!props.disabled){
            events.onClick = this._onClick.bind(this)
        }

        return (
            <a  className="link"  style={theme.link}  {...events}>
                {props.icon &&
                    <i className="icon"  style={this.state.icon}></i>
                }
                <span className="icon-title" style={{color:this.state.color}}>{this.state.title}</span>
            </a>
        )
    }

    componentWillReceiveProps(props) {
        this.state = this._buildStates(props);
    }

    componentWillUnmount(){
       if(this._timer){
           clearTimeout(this._timer);
       }
    }

    /**
     * 通过state控制的只有标题、颜色、图标，来处理按下和恢复时按钮样式
     * @return {{title: (*|string), icon: *, color: (*|$color)}}
     * @private
     */
    _buildStates(props){
        const theme = this._processTheme(props);
        var tics = this._warpArray(props,'title','color', 'icon');
        var title = tics.title[0]||'', icon =theme.icon, color=tics.color[0]||theme.color;
        if(tics.icon[0]){
            Object.assign(theme.icon,{backgroundImage: `url(${tics.icon[0]})`});
        }
        if(props.disabled){
            title = tics.title[2]||title;
            color = tics.color[2]||color;
            if(tics.icon[2]){
                Object.assign(theme.icon,{backgroundImage: `url(${tics.icon[2]})`});
            }
        }else{
            if(tics.icon[0]){
                Object.assign(theme.icon,{backgroundImage: `url(${tics.icon[0]})`});
            }
        }

        var obj = {
            title :title,
            icon: icon,
            color:color
        };


        return obj;
    }

    _processTheme(props){
        var theme = this.theme = getLinkButtonTheme();
        const {iconStyle={},hide=false} = props;
        Object.assign(theme.icon,iconStyle);
        theme.link.display = hide?'none':'-webkit-flex';
        if(props.disabled){
            theme.link.pointerEvents = 'none';
            theme.link.opacity = 0.55;
        }
        return theme;
    }


    //将字符串对象包装成一个数组对象
    _warpArray(obj,...keys){
        let _str2arr = this._str2arr;
        var map = {};
        for(let key of keys){
            map[key] = _str2arr(obj[key])
        }
        return map;
    }

    _str2arr(val){
       if(val == undefined){
           return [];
       }else if(!Array.isArray(val)){
           return [val]
       }else{
            return val;
        }

    }



    _onMouseDown(){
        console.log('mouse down');
        var tics = this._warpArray(this.props,'title','color', 'icon');
        var theme = this.theme;
        var state = {
            title: tics.title[1]||tics.title[0]||'',
            icon: Object.assign({},theme.icon,{backgroundImage: `url(${tics.icon[1]||tics.icon[0]||''})`}),
            color:tics.color[1]||tics.color[0]||theme.color
        };
        this.setState(state);
        return state;

    }

    _onMouseUp(){
        console.log('mouse up');
        let tics = this._warpArray(this.props,'title','color', 'icon');
        let theme = this.theme;
        let state = {
            title: tics.title[0],
            icon: Object.assign({},theme.icon,{backgroundImage: `url(${tics.icon[0]||''})`}),
            color:tics.color[0]||theme.blue
        };
        this._timer = setTimeout(() => {
                this.setState(state);
                this._timer = null;
        });
        return state;
    }

    _onClick(){
        console.log('click')
        const { onClick, scope } = this.props;

        if(onClick){
            onClick.apply(scope)
        }

    }

}

export default LinkButton;
