/**
 * Created with WebStorm.
 * User: gp
 * Date: 16-2-3
 *
 */

import React,{ Component } from 'react'
import getTheme from './styles/navBar'
import LinkButton from './LinkButton'
import Menu from './Menu'

/**
 *  返回按钮和关闭按钮用户不可操控, 根据navationController中存放页面栈长度来确定返回显示不显示
 *  为1时不显示返回按钮, 其它显示
 */
class WebDevNavBar extends Component {

    /*constructor(props, context) {
        super(props, context);
    }*/

    render() {

        //props包含导航栏配置和scope

        const props = this.props;

        const theme = this._processTheme(props);
        const {navbar, navbarInner, leftBar, center} = theme;

        // scope Page实例对象
        const {scope=this,rightButton, rightMenu} = props;

        const rightEl = this._renderRightContent(props, theme);

        const propsColor = this._wrapColor(props);

        return (
            <div className="navbar"  style= {navbar}>
                <div className="navbar-inner" style = {navbarInner}>
                    <div className="left" style={leftBar}>
                        {!scope.isRootPage &&
                            <LinkButton title={['返回']} icon={this._wrapIcon('back',theme,props)} color={propsColor} onClick={this.onBackBtnClicked.bind(this)} iconStyle={{width:'0.32rem',height:'0.53333rem',marginRight:'0.266666rem'}} scope={scope} />
                        }
                        <LinkButton title={['关闭']}  color={propsColor} onClick={this.onCloseBtnClicked.bind(this)} iconStyle={{width:'0.32rem',height:'0.53333rem',marginRight:'0.266666rem'}} scope={scope} />
                    </div>
                    
                    <div className="center" style={center}>{props.title}</div>
                    {rightEl}
                </div>
            </div>
        )
    }

    /**
     * 返回按钮操作
     */
    onBackBtnClicked(){
        // onNavBarLeftClick 左侧容器区域点击事件
        // scope Page实例对象
        const {onBackClick, scope=this} = this.props;

        if(onBackClick){
            onBackClick.apply(scope)
        }else{
            this._goBack();
        }
    }

    /**
     * 关闭按钮操作
     */
    onCloseBtnClicked(){
        // onNavBarLeftClick 左侧容器区域点击事件
        // scope Page实例对象
        const {onCloseClick, scope=this} = this.props;

        if(onCloseClick){
            onCloseClick.apply(scope)
        }else{
            this._closeWin();
        }
    }

    _closeWin(){
        var win = window.open("about:blank", "_self");
        win.close();
    }


    _goBack(){
        history.go(-1);
    }

    /**
     * 处理渲染用到的inline style
     * @param props
     * @private
     */
    _processTheme(props){

        const {hide, left={}, right={},backgroundColor,height, color} = props;
        var theme = getTheme({backgroundColor:backgroundColor, height:height});

        theme['navbar'].display = hide?'none':'';
        var {navbar,leftBar, rightBar,center} = theme;
        leftBar.visibility = left.hide?'hidden':'visible';
        rightBar.visibility = right.hide?'hidden':'visible';
        center.color = color;

        return theme;
    }

    /**
     * 渲染右侧内容
     * @param rightComponent {String|Array} 组件列表配置
     * @return {string}
     * @private
     */
    _renderRightContent(props, theme={}){
        return (
            <div className="right" style={theme.rightBar}>
                {props.right && this._createRightComponent(props, theme)}
            </div>
        );
    }

    /**
     * 根据配置创建右侧容器内的组件
     * @param opt 组件json配置
     * @return {string}
     * @private
     */
    _createRightComponent(props, theme){
        const {right,scope} = props;

        let type = right.type;
        let item = right.item;

        if(type === 'button'){
           let opt = {
               hide: right.hide,
               color: this._wrapColor(props),
               onClick: item.onClick,
               disabled: item.disabled
           }
           let text = item.text;
           if(text && text.length>0){
               opt.title = text;
           }else{
               let iconType = item.icon;
               opt.icon = this._wrapIcon(iconType,theme,props);
           }
           return <LinkButton {...opt}   scope={scope} />
        }else if(type==='menu'){

            return <Menu {...right} color={props.color} highlightColor={props.highlightColor} disabledColor={props.disabledColor} scope={scope} />

        }else{
            throw new Error('右侧容器内可以放置的组件类型目前只支持"button"和"menu"');
        }

    }

    _wrapIcon(type,theme, props){
        const {color,highlightColor,disabledColor} = props;
        return [theme.getIcon(type,color),theme.getIcon(type,highlightColor),theme.getIcon(type,disabledColor)];
    }

    _wrapColor(props){
        return [props.color, props.highlightColor, props.disabledColor];
    }

}

export default WebDevNavBar;
