/**
 * Created with WebStorm.
 * User: gp
 * Date: 16-3-6
 *
 */

import expect from 'expect'
import React from 'react';
import { mount, shallow } from 'enzyme';
import immutable from 'immutable'
import Page from '../../src/page/Page';
//import LinkButton from '../src/LinkButton';
import NavigateBar from '../../src/page/NavigateBar'


describe('Page', () => {

    describe('component', () => {
        function setup(props = {}) {
            const wrapper = shallow(<Page {...props} />);
            return wrapper;
        }
        var props = {};
        function cloneOpts() {
            return immutable.Map(props).toJS();
        }

        describe('render', () => {

            it('应按正确的层次结构渲染', () => {
                let wrapper = setup();
                expect(wrapper.hasClass('page-container')).toBe(true);

                var children = wrapper.children();
                expect(children.length).toBe(2);
                expect(children.first().type()).toBe(NavigateBar);
                expect(children.at(1).hasClass('page-content')).toBe(true);
            })

        describe('hook api function', () => {
            var page = new Page({});

            it('应该包含钩子函数 init', () => {
                expect(page.init()).toBe(null);
            })

            it('应该包含钩子函数 pageBackReceiveResult', () => {
                expect(page.pageBackReceiveResult()).toBe(null);
            })

            it('应该包含钩子函数 renderContent', () => {
                expect(typeof Page.prototype.renderContent == 'function').toBe(true);
            })

            it('应该包含钩子函数 saveInstanceState', () => {
                expect(page.saveInstanceState()).toBe(null);
            })

            it('应该包含钩子函数 restoreInstanceState', () => {
                expect(page.restoreInstanceState()).toBe(null);
            })


        })

        describe('当容器中没有当前页面要恢复的数据时，restoreInstanceState方法不会被调用', () => {
            var _restoreInstanceState = Page.prototype.restoreInstanceState;
            Page.prototype.restoreInstanceState = expect.createSpy();
            new Page({});
            expect(Page.prototype.restoreInstanceState).toNotHaveBeenCalled()
            Page.prototype.restoreInstanceState = _restoreInstanceState;
        })

        describe('当容器中存在当前页面要恢复的数据时，restoreInstanceState方法会被调用', () => {
            var _restoreInstanceState = Page.prototype.restoreInstanceState;
            Page.prototype.restoreInstanceState = expect.createSpy();
            Page.prototype._getSavedInstanceState = function(){return {name:'gp'}};
            new Page({});
            expect(Page.prototype.restoreInstanceState).toHaveBeenCalled()
            Page.prototype.restoreInstanceState = _restoreInstanceState;
        })


       describe('私有方法', () => {


           /*it('将传入的配置对象添加到navBar配置项上', () => {

               instance.resetNavBar({hide:true,left:{hide:true}});
               expect(instance.navBar).toEqual({hide:true,left:{hide:true}});
               instance.resetNavBar({right:{hide:true}});
               expect(instance.navBar).toEqual({hide:true,left:{hide:true},right:{hide:true}})

           })*/

           it('当前环境不是浏览器时，page的padding-top应该为0', ()=> {
               let instance = setup().instance();
               expect(instance._processTheme('weixin').page.paddingTop).toBe(0);
           })

      /*     it('excuteNativeClick被调用时,navBar中对应的onBackClick,onCloseClick,右侧按钮及菜单项事件会被调用执行', () => {
               let instance = setup({}).instance();
               instance.navBar = {
                   onBackClick: expect.createSpy(),
                       onCloseClick: expect.createSpy(),
                       right: {
                       item:{
                           onClick: expect.createSpy()
                       }
                   }
               }
               instance.excuteNativeClick('onBackClick');
               expect(instance.navBar.onBackClick).toHaveBeenCalled();
               instance.excuteNativeClick('onCloseClick');
               expect(instance.navBar.onCloseClick).toHaveBeenCalled();
               instance.excuteNativeClick('right/item/onClick');
               expect(instance.navBar.right.item.onClick).toHaveBeenCalled();

               instance.navBar.right.item = [
                   {onClick:expect.createSpy()},
                   {onClick: expect.createSpy()}
               ]
               instance.excuteNativeClick('right/item/0/onClick');
               expect(instance.navBar.right.item[0].onClick).toHaveBeenCalled();
               instance.excuteNativeClick('right/item/1/onClick');
               expect(instance.navBar.right.item[1].onClick).toHaveBeenCalled();

           })*/


       })




        })
    })



})
